@@ -1,5 +1,5 @@
 from django.contrib import admin
-from django.conf.urls.defaults import patterns, url, include
+from django.conf.urls import patterns, url, include
 
 
 urlpatterns = patterns('',
